<?php

class DSSB_SharingButton extends ET_Builder_Module {

	public function init() {

		$this->vb_support      = 'on';
		$this->slug            = 'dssb_sharing_button';
		$this->type            = 'child';
		$this->child_title_var = 'social_network';
		$this->name            = esc_html__( 'Sharing Button', 'dssb-divi-social-sharing-buttons' );

		$this->settings_modal_toggles = array(
			'general'  => array(
				'toggles' => array(
					'network'    => esc_html__( 'Network', 'dssb-divi-social-sharing-buttons' ),
					'share_text' => esc_html__( 'Share Text', 'dssb-divi-social-sharing-buttons' ),
				),
			),

			'advanced' => array(
				'toggles' => array(
					'icon'       => esc_html__( 'Icon', 'dssb-divi-social-sharing-buttons' ),
					'share_text' => esc_html__( 'Share Text', 'dssb-divi-social-sharing-buttons' ),
					'borders'    => esc_html__( 'Borders', 'dssb-divi-social-sharing-buttons' ),
				),
			),
		);
	}

	public function get_fields() {
		$fields = array(

			'social_network'       => array(
				'label'       => esc_html__( 'Social Network', 'dssb-divi-social-sharing-buttons' ),
				'description' => esc_html__( 'Select a social network to show as a sharing button.', 'dssb-divi-social-sharing-buttons' ),
				'type'        => 'select',
				'toggle_slug' => 'network',
				'default'     => 'facebook',
				'options'     => array(
					'facebook'  => esc_html__( 'Facebook', 'dssb-divi-social-sharing-buttons' ),
					'twitter'   => esc_html__( 'Twitter', 'dssb-divi-social-sharing-buttons' ),
					'pinterest' => esc_html__( 'Pinterest', 'dssb-divi-social-sharing-buttons' ),
					'linkedin'  => esc_html__( 'LinkedIn', 'dssb-divi-social-sharing-buttons' ),
					'whatsapp'  => esc_html__( 'WhatsApp', 'dssb-divi-social-sharing-buttons' ),
					'tumblr'    => esc_html__( 'Tumblr', 'dssb-divi-social-sharing-buttons' ),
					'reddit'    => esc_html__( 'Reddit', 'dssb-divi-social-sharing-buttons' ),
					'email'     => esc_html__( 'Email', 'dssb-divi-social-sharing-buttons' ),
				),
			),

			'share_text'           => array(
				'label'           => esc_html__( 'Custom Text', 'dssb-divi-social-sharing-buttons' ),
				'type'            => 'text',
				'option_category' => 'basic_option',
				'description'     => esc_html__( 'Enter custom button text.', 'dssb-divi-social-sharing-buttons' ),
				'toggle_slug'     => 'share_text',
			),

			'icon_color'           => array(
				'label'       => esc_html__( 'Icon Color', 'dssb-divi-social-sharing-buttons' ),
				'description' => esc_html__( 'Set a color for the social network icon.', 'dssb-divi-social-sharing-buttons' ),
				'type'        => 'color-alpha',
				'tab_slug'    => 'advanced',
				'toggle_slug' => 'icon',
			),

			'use_custom_icon_size' => array(
				'label'       => esc_html__( 'Use Custom Icon Size', 'dssb-divi-social-sharing-buttons' ),
				'description' => esc_html__( 'Enable this setting to control the size of the social network icon.', 'dssb-divi-social-sharing-buttons' ),
				'type'        => 'yes_no_button',
				'options'     => array(
					'on'  => esc_html__( 'Yes', 'dssb-divi-social-sharing-buttons' ),
					'off' => esc_html__( 'No', 'dssb-divi-social-sharing-buttons' ),
				),
				'default'     => 'off',
				'tab_slug'    => 'advanced',
				'toggle_slug' => 'icon',
			),

			'icon_font_size'       => array(
				'label'          => esc_html__( 'Icon Font Size', 'dssb-divi-social-sharing-buttons' ),
				'description'    => esc_html__( 'Set the size of the social network icon.', 'dssb-divi-social-sharing-buttons' ),
				'type'           => 'range',
				'mobile_options' => true,
				'fixed_unit'     => 'px',
				'range_settings' => array(
					'min'  => 0,
					'step' => 1,
					'max'  => 200,
				),
				'tab_slug'       => 'advanced',
				'toggle_slug'    => 'icon',
				'show_if'        => array(
					'use_custom_icon_size' => 'on',
				),
			),

			'icon_bg'              => array(
				'label'       => esc_html__( 'Icon Background Color', 'dssb-divi-social-sharing-buttons' ),
				'description' => esc_html__( 'Set the background color for the social network icon.', 'dssb-divi-social-sharing-buttons' ),
				'type'        => 'color-alpha',
				'tab_slug'    => 'advanced',
				'toggle_slug' => 'icon',
			),

		);

		return $fields;
	}

	public function get_advanced_fields_config() {

		$advanced_fields                 = array();
		$advanced_fields['text']         = false;
		$advanced_fields['text_shadow']  = false;
		$advanced_fields['fonts']        = false;
		$advanced_fields['link_options'] = false;

		$advanced_fields['margin_padding'] = array(
			'css' => array(
				'margin'    => '%%order_class%% .dssb-sharing-button',
				'padding'   => '%%order_class%% .dssb-sharing-button',
				'important' => 'all',
			),
		);

		$advanced_fields['borders']['item'] = array(
			'toggle_slug' => 'borders',
			'css'         => array(
				'main'      => array(
					'border_radii'  => '.dssb-sharing-buttons %%order_class%% .dssb-sharing-button',
					'border_styles' => '.dssb-sharing-buttons %%order_class%% .dssb-sharing-button',
				),
				'important' => 'all',
			),
			'defaults'    => array(
				'border_radii'  => 'on|0px|0px|0px|0px',
				'border_styles' => array(
					'width' => '0px',
					'color' => '#333',
					'style' => 'solid',
				),
			),
		);

		$advanced_fields['borders']['icon'] = array(
			'label_prefix' => esc_html__( 'Icon', 'dssb-divi-social-sharing-buttons' ),
			'toggle_slug'  => 'icon',
			'css'          => array(
				'main'      => array(
					'border_radii'  => '.dssb-sharing-buttons %%order_class%% .dssb-sharing-icon',
					'border_styles' => '.dssb-sharing-buttons %%order_class%% .dssb-sharing-icon',
				),
				'important' => 'all',
			),
			'defaults'     => array(
				'border_radii'  => 'on|0px|0px|0px|0px',
				'border_styles' => array(
					'width' => '0px',
					'color' => '#333',
					'style' => 'solid',
				),
			),
		);

		$advanced_fields['fonts']['share'] = array(
			'label'       => esc_html__( 'Share Text', 'dssb-divi-social-sharing-buttons' ),
			'css'         => array(
				'main'      => '.dssb-sharing-buttons %%order_class%% .dssb-sharing-text',
				'important' => 'all',
			),
			'tab_slug'    => 'advanced',
			'toggle_slug' => 'share_text',
			'line_height' => array(
				'range_settings' => array(
					'min'  => '1',
					'max'  => '100',
					'step' => '1',
				),
			),
		);

		$advanced_fields['box_shadow']['icon'] = array(
			'label'       => esc_html__( 'Icon Box Shadow', 'dssb-divi-social-sharing-buttons' ),
			'toggle_slug' => 'icon',
			'css'         => array(
				'main'      => '.dssb-sharing-buttons %%order_class%% .dssb-sharing-icon',
				'important' => 'all',
			),
		);

		$advanced_fields['background'] = array(
			'css' => array(
				'important' => true,
				'main'      => '%%order_class%% .dssb-sharing-button',
			),
		);

		return $advanced_fields;
	}

	public function render( $attrs, $content = null, $render_slug ) {

		$this->_render_css( $render_slug );

		$this->remove_classname(
			array(
				'et_pb_module',
				'et_pb_section_video',
				'et_pb_preload',
				'et_pb_section_parallax',
			)
		);

		$social_network = $this->props['social_network'];
		$share_text     = $this->props['share_text'];

		if ( empty( $share_text ) ) {
			$share_text = 'Share on ' . ucwords( $social_network, '' );
		}

		return sprintf(
			'
            <div class="dssb-sharing-button">
                <a class="dssb-sharing-button-%1$s" href="#">
                    <span class="dssb-sharing-icon dssb-sharing-%1$s"></span>
                    <div class="dssb-sharing-text">%2$s</div>
                </a>
            </div>',
			$social_network,
			$share_text
		);
	}

	public function _render_css( $render_slug ) {

		$icon_color                       = $this->props['icon_color'];
		$use_custom_icon_size             = $this->props['use_custom_icon_size'];
		$icon_font_size                   = $this->props['icon_font_size'];
		$icon_font_size_tablet            = $this->props['icon_font_size_tablet'];
		$icon_font_size_phone             = $this->props['icon_font_size_phone'];
		$icon_font_size_last_edited       = $this->props['icon_font_size_last_edited'];
		$icon_font_size_responsive_status = et_pb_get_responsive_status( $icon_font_size_last_edited );
		$icon_bg                          = $this->props['icon_bg'];
		$social_network                   = $this->props['social_network'];

		if ( empty( $background_color ) ) {
			$colors = array(
				'facebook'  => '#3b5998',
				'twitter'   => '#00aced',
				'pinterest' => '#cb2027',
				'linkedin'  => '#007bb6',
				'whatsapp'  => '#4AC959',
				'reddit'    => '#FF5700',
				'tumblr'    => '#34526f',
				'email'     => '#333333',
			);
			ET_Builder_Element::set_style(
				$render_slug,
				array(
					'selector'    => '.dssb_sharing_buttons %%order_class%% .dssb-sharing-button',
					'declaration' => "background:{$colors[$social_network]};",
				)
			);
		}

		if ( ! empty( $icon_color ) ) {
			ET_Builder_Element::set_style(
				$render_slug,
				array(
					'selector'    => '.dssb-sharing-buttons %%order_class%% .dssb-sharing-icon',
					'declaration' => "color: {$icon_color};",
				)
			);
		}

		if ( ! empty( $icon_bg ) ) {
			\ET_Builder_Element::set_style(
				$render_slug,
				array(
					'selector'    => '.dssb-sharing-buttons %%order_class%% .dssb-sharing-icon',
					'declaration' => "background: {$icon_bg};",
				)
			);
		}

		if ( $use_custom_icon_size === 'on' && ! empty( $icon_font_size ) ) {
			ET_Builder_Element::set_style(
				$render_slug,
				array(
					'selector'    => '.dssb-sharing-buttons %%order_class%% .dssb-sharing-icon',
					'declaration' => sprintf(
						'
                    font-size: %1$s;
                    height: calc(2 * %1$s);
                    width: calc(2 * %1$s);',
						$icon_font_size
					),
				)
			);

			if ( $icon_font_size_tablet && $icon_font_size_responsive_status ) {
				ET_Builder_Element::set_style(
					$render_slug,
					array(
						'selector'    => '.dssb-sharing-buttons %%order_class%% .dssb-sharing-icon',
						'media_query' => ET_Builder_Element::get_media_query( 'max_width_980' ),
						'declaration' => sprintf(
							'
                        font-size: %1$s;
                        height: calc(2 * %1$s);
                        width: calc(2 * %1$s);',
							$icon_font_size_tablet
						),
					)
				);

			}

			if ( $icon_font_size_phone && $icon_font_size_responsive_status ) {
				ET_Builder_Element::set_style(
					$render_slug,
					array(
						'selector'    => '.dssb-sharing-buttons %%order_class%% .dssb-sharing-icon',
						'media_query' => ET_Builder_Element::get_media_query( 'max_width_767' ),
						'declaration' => sprintf(
							'
                        font-size: %1$s;
                        height: calc(2 * %1$s);
                        width: calc(2 * %1$s);',
							$icon_font_size_phone
						),
					)
				);

			}
		}
	}
}

new DSSB_SharingButton();
