<?php

class DSSB_SharingButtons extends ET_Builder_Module {

	protected $module_credits = array(
		'module_uri' => 'https://www.peeayecreative.com/',
		'author'     => 'Pee-Aye Creative',
		'author_uri' => 'https://www.peeayecreative.com/',
	);

	public function init() {

		$this->vb_support = 'on';
		$this->slug       = 'dssb_sharing_buttons';
		$this->child_slug = 'dssb_sharing_button';
		$this->name       = esc_html__( 'Social Sharing Buttons', 'dssb-divi-social-sharing-buttons' );

		$this->settings_modal_toggles = array(
			'advanced' => array(
				'toggles' => array(
					'layout'     => esc_html( 'Layout', 'dssb-divi-social-sharing-buttons' ),
					'icon'       => esc_html( 'Icon', 'dssb-divi-social-sharing-buttons' ),
					'share_text' => esc_html( 'Share Text', 'dssb-divi-social-sharing-buttons' ),
					'borders'    => esc_html( 'Borders', 'dssb-divi-social-sharing-buttons' ),
				),
			),
		);
	}

	public function get_advanced_fields_config() {

		$advanced_fields                 = array();
		$advanced_fields['text']         = false;
		$advanced_fields['text_shadow']  = false;
		$advanced_fields['fonts']        = false;
		$advanced_fields['link_options'] = false;

		$advanced_fields['borders']['main'] = array(
			'label_prefix' => esc_html__( 'Button', 'dssb-divi-social-sharing-buttons' ),
			'toggle_slug'  => 'borders',
			'css'          => array(
				'main' => array(
					'border_radii'  => '%%order_class%% .dssb-sharing-button',
					'border_styles' => '%%order_class%% .dssb-sharing-button',
				),
			),
			'defaults'     => array(
				'border_radii'  => 'on|0px|0px|0px|0px',
				'border_styles' => array(
					'width' => '0px',
					'color' => '#333',
					'style' => 'solid',
				),
			),
		);

		$advanced_fields['borders']['icon'] = array(
			'label_prefix' => esc_html__( 'Icon Border Settings', 'dssb-divi-social-sharing-buttons' ),
			'toggle_slug'  => 'icon',
			'css'          => array(
				'main'      => array(
					'border_radii'  => '%%order_class%% .dssb-sharing-icon',
					'border_styles' => '%%order_class%% .dssb-sharing-icon',
				),
				'important' => 'all',
			),
			'defaults'     => array(
				'border_radii'  => 'on|0px|0px|0px|0px',
				'border_styles' => array(
					'width' => '0px',
					'color' => '#333',
					'style' => 'solid',
				),
			),
		);

		$advanced_fields['fonts']['share'] = array(
			'label'       => esc_html__( 'Share Text', 'dssb-divi-social-sharing-buttons' ),
			'css'         => array(
				'main'      => '%%order_class%% .dssb-sharing-text',
				'important' => 'all',
			),
			'tab_slug'    => 'advanced',
			'toggle_slug' => 'share_text',
			'line_height' => array(
				'range_settings' => array(
					'min'  => '1',
					'max'  => '100',
					'step' => '1',
				),
			),
		);

		$advanced_fields['box_shadow']['icon'] = array(
			'label'       => esc_html__( 'Icon Box Shadow Settings', 'dssb-divi-social-sharing-buttons' ),
			'toggle_slug' => 'icon',
			'css'         => array(
				'main'      => '%%order_class%% .dssb-sharing-icon',
				'important' => 'all',
			),
		);

		return $advanced_fields;
	}

	public function get_fields() {

		$fields = array(

			'icon_placement'       => array(
				'label'       => esc_html__( 'Button Icon And Text Layout', 'dssb-divi-social-sharing-buttons' ),
				'description' => esc_html__( 'Choose where to place the icon in relation to the text.', 'dssb-divi-social-sharing-buttons' ),
				'type'        => 'select',
				'toggle_slug' => 'layout',
				'tab_slug'    => 'advanced',
				'default'     => 'icon_left',
				'options'     => array(
					'icon_left' => esc_html__( 'Icon Left, Text Right', 'dssb-divi-social-sharing-buttons' ),
					'icon_top'  => esc_html__( 'Icon Top, Text Bottom', 'dssb-divi-social-sharing-buttons' ),
					'icon'      => esc_html__( 'Icon Only, No Text', 'dssb-divi-social-sharing-buttons' ),
					'text'      => esc_html__( 'Text Only, No Icon', 'dssb-divi-social-sharing-buttons' ),
				),
			),

			'alignment'            => array(
				'label'           => esc_html__( 'Alignment', 'dssb-divi-social-sharing-buttons' ),
				'description'     => esc_html__( 'Set the alignment for the group of icons.', 'dssb-divi-social-sharing-buttons' ),
				'type'            => 'text_align',
				'option_category' => 'layout',
				'show_if'         => array(
					'icon_placement' => 'icon',
				),
				'options'         => et_builder_get_text_orientation_options( array( 'justified' ) ),
				'mobile_options'  => true,
				'options_icon'    => 'module_align',
				'default'         => 'center',
				'toggle_slug'     => 'layout',
				'tab_slug'        => 'advanced',
			),

			'columns'              => array(
				'label'          => esc_html__( 'Number Of Columns', 'dssb-divi-social-sharing-buttons' ),
				'description'    => esc_html__( 'Set the number of columns for the buttons on each device.', 'dssb-divi-social-sharing-buttons' ),
				'type'           => 'range',
				'default'        => '4',
				'mobile_options' => true,
				'unitless'       => true,
				'range_settings' => array(
					'min'  => 1,
					'step' => 1,
					'max'  => 12,
				),
				'show_if'        => array(
					'icon_placement' => array( 'text', 'icon_top', 'icon_left' ),
				),
				'toggle_slug'    => 'layout',
				'tab_slug'       => 'advanced',
			),

			'icon_color'           => array(
				'label'       => esc_html__( 'Icon Color', 'dssb-divi-social-sharing-buttons' ),
				'type'        => 'color-alpha',
				'description' => esc_html__( 'Set a color for the social network icon.', 'dssb-divi-social-sharing-buttons' ),
				'tab_slug'    => 'advanced',
				'toggle_slug' => 'icon',
				'default'     => '#ffffff',
			),

			'use_custom_icon_size' => array(
				'label'       => esc_html__( 'Use Custom Icon Size', 'dssb-divi-social-sharing-buttons' ),
				'description' => esc_html__( 'Enable this setting to control the size of the social network icon.', 'dssb-divi-social-sharing-buttons' ),
				'type'        => 'yes_no_button',
				'options'     => array(
					'on'  => esc_html__( 'Yes', 'dssb-divi-social-sharing-buttons' ),
					'off' => esc_html__( 'No', 'dssb-divi-social-sharing-buttons' ),
				),
				'default'     => 'off',
				'tab_slug'    => 'advanced',
				'toggle_slug' => 'icon',
			),

			'icon_font_size'       => array(
				'label'          => esc_html__( 'Icon Font Size', 'dssb-divi-social-sharing-buttons' ),
				'description'    => esc_html__( 'Set the size of the social network icon.', 'dssb-divi-social-sharing-buttons' ),
				'type'           => 'range',
				'mobile_options' => true,
				'fixed_unit'     => 'px',
				'range_settings' => array(
					'min'  => 0,
					'step' => 1,
					'max'  => 200,
				),
				'tab_slug'       => 'advanced',
				'toggle_slug'    => 'icon',
				'show_if'        => array(
					'use_custom_icon_size' => 'on',
				),
			),

			'icon_bg'              => array(
				'label'       => esc_html__( 'Icon Background Color', 'dssb-divi-social-sharing-buttons' ),
				'description' => esc_html__( 'Set the background color for the social network icon.', 'dssb-divi-social-sharing-buttons' ),
				'type'        => 'color-alpha',
				'tab_slug'    => 'advanced',
				'toggle_slug' => 'icon',
			),

			'icon_padding'         => array(
				'label'          => esc_html__( 'Icon Padding', 'dssb-divi-social-sharing-buttons' ),
				'description'    => esc_html__( 'Adjust the inner spacing of the icons.', 'dssb-divi-social-sharing-buttons' ),
				'type'           => 'range',
				'mobile_options' => true,
				'fixed_unit'     => 'px',
				'range_settings' => array(
					'min'  => 0,
					'step' => 1,
					'max'  => 200,
				),
				'tab_slug'       => 'advanced',
				'toggle_slug'    => 'margin_padding',
				'show_if'        => array(
					'icon_placement' => array( 'icon_top', 'icon_left', 'icon'),
				),
			),

			'btn_spacing'          => array(
				'label'          => esc_html__( 'Button Spacing Between', 'dssb-divi-social-sharing-buttons' ),
				'description'    => esc_html__( 'Adjust the spacing between the individual buttons.', 'dssb-divi-social-sharing-buttons' ),
				'type'           => 'range',
				'default'        => '10px',
				'mobile_options' => true,
				'fixed_unit'     => 'px',
				'range_settings' => array(
					'min'  => 0,
					'step' => 1,
					'max'  => 200,
				),
				'tab_slug'       => 'advanced',
				'toggle_slug'    => 'margin_padding',
			),

			'btn_spacing_bottom'   => array(
				'label'          => esc_html__( 'Button Spacing Bottom', 'dssb-divi-social-sharing-buttons' ),
				'description'    => esc_html__( 'Adjust the spacing below the individual buttons.', 'dssb-divi-social-sharing-buttons' ),
				'type'           => 'range',
				'default'        => '10px',
				'mobile_options' => true,
				'fixed_unit'     => 'px',
				'range_settings' => array(
					'min'  => 0,
					'step' => 1,
					'max'  => 200,
				),
				'tab_slug'       => 'advanced',
				'toggle_slug'    => 'margin_padding',
			),

			'btn_padding'          => array(
				'label'       => esc_html__( 'Button Padding', 'dssb-divi-social-sharing-buttons' ),
				'description' => esc_html__( 'Adjust the inner spacing of the buttons.', 'dssb-divi-social-sharing-buttons' ),
				'type'        => 'custom_padding',
				'tab_slug'    => 'advanced',
				'toggle_slug' => 'margin_padding',
			),

		);

		return $fields;
	}

	public function render( $attrs, $content = null, $render_slug ) {

		$this->_render_css( $render_slug );

		$icon_placement            = $this->props['icon_placement'];
		$columns                   = 'icon' !== $icon_placement ? $this->props['columns'] : 'none';
		$columns_last_edited       = $this->props['columns_last_edited'];
		$columns_responsive_status = et_pb_get_responsive_status( $columns_last_edited );
		$columns_tablet            = $columns_responsive_status && 'icon' !== $icon_placement ? $this->props['columns_tablet'] : $columns;
		$columns_phone             = $columns_responsive_status && 'icon' !== $icon_placement ? $this->props['columns_phone'] : $columns_tablet;

		return sprintf(
			'<div class="dssb-sharing-buttons dssb-columns-%2$s dssb-tablet-columns-%3$s dssb-phone-columns-%4$s">
				%1$s
			</div>',
			$this->props['content'],
			$columns,
			$columns_tablet,
			$columns_phone
		);
	}

	public function _render_css( $render_slug ) {

		$icon_color                           = $this->props['icon_color'];
		$use_custom_icon_size                 = $this->props['use_custom_icon_size'];
		$icon_font_size                       = $this->props['icon_font_size'];
		$icon_font_size_tablet                = $this->props['icon_font_size_tablet'];
		$icon_font_size_phone                 = $this->props['icon_font_size_phone'];
		$icon_font_size_last_edited           = $this->props['icon_font_size_last_edited'];
		$icon_font_size_responsive_status     = et_pb_get_responsive_status( $icon_font_size_last_edited );
		$icon_bg                              = $this->props['icon_bg'];
		$icon_placement                       = $this->props['icon_placement'];
		$btn_padding                          = $this->props['btn_padding'];
		$btn_spacing                          = $this->props['btn_spacing'];
		$btn_spacing_tablet                   = $this->props['btn_spacing_tablet'];
		$btn_spacing_phone                    = $this->props['btn_spacing_phone'];
		$btn_spacing_last_edited              = $this->props['btn_spacing_last_edited'];
		$btn_spacing_responsive_status        = et_pb_get_responsive_status( $btn_spacing_last_edited );
		$btn_spacing_bottom                   = $this->props['btn_spacing_bottom'];
		$btn_spacing_bottom_tablet            = $this->props['btn_spacing_bottom_tablet'];
		$btn_spacing_bottom_phone             = $this->props['btn_spacing_bottom_phone'];
		$btn_spacing_bottom_last_edited       = $this->props['btn_spacing_bottom_last_edited'];
		$btn_spacing_bottom_responsive_status = et_pb_get_responsive_status( $btn_spacing_bottom_last_edited );

		$alignment                   = $this->props['alignment'];
		$alignment_last_edited       = $this->props['alignment_last_edited'];
		$alignment_responsive_status = et_pb_get_responsive_status( $alignment_last_edited );
		$alignment_tablet            = $alignment_responsive_status ? $this->props['alignment_tablet'] : $alignment;
		$alignment_phone             = $alignment_responsive_status ? $this->props['alignment_phone'] : $alignment_tablet;

		if ( empty( $btn_padding ) ) {
			if ( 'icon_left' === $icon_placement ) {
				ET_Builder_Element::set_style(
					$render_slug,
					array(
						'selector'    => '%%order_class%% .dssb-sharing-button',
						'declaration' => 'padding-right:20px;',
					)
				);
			} elseif ( 'icon_top' === $icon_placement ) {
				ET_Builder_Element::set_style(
					$render_slug,
					array(
						'selector'    => '%%order_class%% .dssb-sharing-button',
						'declaration' => 'padding:20px;',
					)
				);
			} elseif ( 'text' === $icon_placement ) {
				ET_Builder_Element::set_style(
					$render_slug,
					array(
						'selector'    => '%%order_class%% .dssb-sharing-icon',
						'declaration' => 'display: none !important;',
					)
				);
				ET_Builder_Element::set_style(
					$render_slug,
					array(
						'selector'    => '%%order_class%% .dssb-sharing-button',
						'declaration' => 'padding: 10px 20px;',
					)
				);
			}
		} else {
			$btn_padding = explode( '|', $btn_padding );
			\ET_Builder_Element::set_style(
				$render_slug,
				array(
					'selector'    => '%%order_class%% .dssb-sharing-button',
					'declaration' => sprintf(
						'
                    padding-top:%1$s;
                    padding-right:%2$s;
                    padding-bottom:%3$s;
                    padding-left:%4$s;',
						$btn_padding[0],
						$btn_padding[1],
						$btn_padding[2],
						$btn_padding[3]
					),
				)
			);

		}

		ET_Builder_Element::set_style(
			$render_slug,
			array(
				'selector'    => '%%order_class%% .dssb-sharing-button',
				'declaration' => "margin-right:{$btn_spacing};",
			)
		);

		if ( $btn_spacing_tablet && $btn_spacing_responsive_status ) {
			ET_Builder_Element::set_style(
				$render_slug,
				array(
					'selector'    => '%%order_class%% .dssb-sharing-button',
					'media_query' => ET_Builder_Element::get_media_query( 'max_width_980' ),
					'declaration' => "margin-right:{$btn_spacing_tablet};",
				)
			);
		}

		if ( $btn_spacing_phone && $btn_spacing_responsive_status ) {
			ET_Builder_Element::set_style(
				$render_slug,
				array(
					'selector'    => '%%order_class%% .dssb_sharing_button',
					'media_query' => ET_Builder_Element::get_media_query( 'max_width_767' ),
					'declaration' => "margin-right:{$btn_spacing_phone};",
				)
			);
		}

		\ET_Builder_Element::set_style(
			$render_slug,
			array(
				'selector'    => '%%order_class%% .dssb-sharing-buttons .dssb-sharing-button',
				'declaration' => "margin-bottom:{$btn_spacing_bottom}!important;",
			)
		);

		if ( $btn_spacing_bottom_tablet && $btn_spacing_bottom_responsive_status ) {
			ET_Builder_Element::set_style(
				$render_slug,
				array(
					'selector'    => '%%order_class%% .dssb-sharing-buttons .dssb_sharing_button',
					'media_query' => ET_Builder_Element::get_media_query( 'max_width_980' ),
					'declaration' => "margin-bottom:{$btn_spacing_tablet}!important;",
				)
			);
		}

		if ( $btn_spacing_bottom_phone && $btn_spacing_bottom_responsive_status ) {
			ET_Builder_Element::set_style(
				$render_slug,
				array(
					'selector'    => '%%order_class%% .dssb-sharing-buttons .dssb_sharing_button',
					'media_query' => ET_Builder_Element::get_media_query( 'max_width_767' ),
					'declaration' => "margin-bottom:{$btn_spacing_bottom_phone}!important;",
				)
			);
		}

		if ( 'icon' === $icon_placement ) {
			ET_Builder_Element::set_style(
				$render_slug,
				array(
					'selector'    => '%%order_class%% .dssb-sharing-buttons',
					'declaration' => 'flex-wrap: unset !important;',
				)
			);

			ET_Builder_Element::set_style(
				$render_slug,
				array(
					'selector'    => '%%order_class%% .dssb-sharing-buttons',
					'media_query' => ET_Builder_Element::get_media_query( 'max_width_767' ),
					'declaration' => 'flex-wrap: wrap !important;',
				)
			);

			if ( 'left' === $alignment ) {
				ET_Builder_Element::set_style(
					$render_slug,
					array(
						'selector'    => '%%order_class%% .dssb-sharing-buttons',
						'declaration' => 'justify-content: flex-start;',
					)
				);
			} elseif ( 'center' === $alignment ) {
				ET_Builder_Element::set_style(
					$render_slug,
					array(
						'selector'    => '%%order_class%% .dssb-sharing-buttons',
						'declaration' => 'justify-content: center;',
					)
				);
			} else {
				ET_Builder_Element::set_style(
					$render_slug,
					array(
						'selector'    => '%%order_class%% .dssb-sharing-buttons',
						'declaration' => 'justify-content: flex-end;',
					)
				);
			}

			if ( 'left' === $alignment_tablet ) {
				ET_Builder_Element::set_style(
					$render_slug,
					array(
						'selector'    => '%%order_class%% .dssb-sharing-buttons',
						'media_query' => ET_Builder_Element::get_media_query( 'max_width_980' ),
						'declaration' => 'justify-content: flex-start;',
					)
				);
			} elseif ( 'center' === $alignment_tablet ) {
				ET_Builder_Element::set_style(
					$render_slug,
					array(
						'selector'    => '%%order_class%% .dssb-sharing-buttons',
						'media_query' => ET_Builder_Element::get_media_query( 'max_width_980' ),
						'declaration' => 'justify-content: center;',
					)
				);
			} else {
				ET_Builder_Element::set_style(
					$render_slug,
					array(
						'selector'    => '%%order_class%% .dssb-sharing-buttons',
						'media_query' => ET_Builder_Element::get_media_query( 'max_width_980' ),
						'declaration' => 'justify-content: flex-end;',
					)
				);
			}

			if ( 'left' === $alignment_phone ) {
				ET_Builder_Element::set_style(
					$render_slug,
					array(
						'selector'    => '%%order_class%% .dssb-sharing-buttons',
						'media_query' => ET_Builder_Element::get_media_query( 'max_width_767' ),
						'declaration' => 'justify-content: flex-start;',
					)
				);
			} elseif ( 'center' === $alignment_phone ) {
				ET_Builder_Element::set_style(
					$render_slug,
					array(
						'selector'    => '%%order_class%% .dssb-sharing-buttons',
						'media_query' => ET_Builder_Element::get_media_query( 'max_width_767' ),
						'declaration' => 'justify-content: center;',
					)
				);
			} else {
				ET_Builder_Element::set_style(
					$render_slug,
					array(
						'selector'    => '%%order_class%% .dssb-sharing-buttons',
						'media_query' => ET_Builder_Element::get_media_query( 'max_width_767' ),
						'declaration' => 'justify-content: flex-end;',
					)
				);
			}

			ET_Builder_Element::set_style(
				$render_slug,
				array(
					'selector'    => '%%order_class%% .dssb-sharing-text',
					'declaration' => 'display: none;',
				)
			);

			ET_Builder_Element::set_style(
				$render_slug,
				array(
					'selector'    => '%%order_class%% .dssb-sharing-button',
					'declaration' => 'background: transparent;',
				)
			);

		} elseif ( 'text' === $icon_placement ) {
			ET_Builder_Element::set_style(
				$render_slug,
				array(
					'selector'    => '%%order_class%% .dssb-sharing-icon',
					'declaration' => 'display: none;',
				)
			);
		} elseif ( 'icon_top' === $icon_placement ) {

			ET_Builder_Element::set_style(
				$render_slug,
				array(
					'selector'    => '%%order_class%% .dssb-sharing-button a',
					'declaration' => 'flex-direction: column; justify-content: center;',
				)
			);

			ET_Builder_Element::set_style(
				$render_slug,
				array(
					'selector'    => '%%order_class%% .dssb-sharing-buttons .dssb-sharing-text',
					'declaration' => 'text-align: center;',
				)
			);

			ET_Builder_Element::set_style(
				$render_slug,
				array(
					'selector'    => '%%order_class%% .dssb-sharing-icon',
					'declaration' => 'margin-bottom: 20px;',
				)
			);

		} elseif ( 'icon_left' === $icon_placement ) {

			ET_Builder_Element::set_style(
				$render_slug,
				array(
					'selector'    => '%%order_class%% .dssb-sharing-icon',
					'declaration' => 'margin-right: 20px;',
				)
			);

		}

		ET_Builder_Element::set_style(
			$render_slug,
			array(
				'selector'    => '%%order_class%% .dssb-sharing-icon',
				'declaration' => "color: {$icon_color};",
			)
		);

		if ( ! empty( $icon_bg ) ) {
			\ET_Builder_Element::set_style(
				$render_slug,
				array(
					'selector'    => '%%order_class%% .dssb-sharing-icon',
					'declaration' => "background: {$icon_bg};",
				)
			);
		} else {
			\ET_Builder_Element::set_style(
				$render_slug,
				array(
					'selector'    => '%%order_class%% .dssb-sharing-icon',
					'declaration' => 'background: rgba(0,0,0,.2);',
				)
			);
		}

		if ( $use_custom_icon_size === 'on' ) {
			ET_Builder_Element::set_style(
				$render_slug,
				array(
					'selector'    => '%%order_class%% .dssb-sharing-icon',
					'declaration' => sprintf(
						'
                    font-size: %1$s;
                    height: calc(2 * %1$s);
                    width: calc(2 * %1$s);',
						$icon_font_size
					),
				)
			);

			if ( $icon_font_size_tablet && $icon_font_size_responsive_status ) {
				ET_Builder_Element::set_style(
					$render_slug,
					array(
						'selector'    => '%%order_class%% .dssb-sharing-icon',
						'media_query' => ET_Builder_Element::get_media_query( 'max_width_980' ),
						'declaration' => sprintf(
							'
                        font-size: %1$s;
                        height: calc(2 * %1$s);
                        width: calc(2 * %1$s);',
							$icon_font_size_tablet
						),
					)
				);
			}

			if ( $icon_font_size_phone && $icon_font_size_responsive_status ) {
				ET_Builder_Element::set_style(
					$render_slug,
					array(
						'selector'    => '%%order_class%% .dssb-sharing-icon',
						'media_query' => ET_Builder_Element::get_media_query( 'max_width_767' ),
						'declaration' => sprintf(
							'
                        font-size: %1$s;
                        height: calc(2 * %1$s);
                        width: calc(2 * %1$s);',
							$icon_font_size_phone
						),
					)
				);
			}
		} else {
			ET_Builder_Element::set_style(
				$render_slug,
				array(
					'selector'    => '%%order_class%% .dssb-sharing-icon',
					'declaration' => sprintf(
						'
                    font-size: 20px;
                    height: 40px;
                    width: 40px;'
					),
				)
			);
		}

		$icon_padding                   = $this->props['icon_padding'];
		$icon_padding_last_edited       = $this->props['icon_padding_last_edited'];
		$icon_padding_responsive_status = et_pb_get_responsive_status( $icon_padding_last_edited );
		$icon_padding_tablet            = $this->props['icon_padding_tablet'];
		$icon_padding_phone             = $this->props['icon_padding_phone'];

		if ( $icon_padding ) {
			ET_Builder_Element::set_style(
				$render_slug,
				array(
					'selector'    => '%%order_class%% .dssb-sharing-icon',
					'declaration' => "padding: {$icon_padding}",
				)
			);

			if ( $icon_padding_responsive_status ) {
				ET_Builder_Element::set_style(
					$render_slug,
					array(
						'selector'    => '%%order_class%% .dssb-sharing-icon',
						'media_query' => ET_Builder_Element::get_media_query( 'max_width_980' ),
						'declaration' => "padding: {$icon_padding_tablet}",
					)
				);

				ET_Builder_Element::set_style(
					$render_slug,
					array(
						'selector'    => '%%order_class%% .dssb-sharing-icon',
						'media_query' => ET_Builder_Element::get_media_query( 'max_width_767' ),
						'declaration' => "padding: {$icon_padding_phone}",
					)
				);
			}
		} else {

			if ( $use_custom_icon_size === 'on' ) {
				ET_Builder_Element::set_style(
					$render_slug,
					array(
						'selector'    => '%%order_class%% .dssb-sharing-icon',
						'declaration' => "padding: {$icon_font_size}",
					)
				);
			} else {
				ET_Builder_Element::set_style(
					$render_slug,
					array(
						'selector'    => '%%order_class%% .dssb-sharing-icon',
						'declaration' => 'padding: 20px',
					)
				);
			}
		}

	}
}

new DSSB_SharingButtons();
